@@ -1,4 +1,4 @@
-/* Copyright (C) 2008-2015 D. V. Wiebe
+/* Copyright (C) 2008-2016 D. V. Wiebe
  *
  ***************************************************************************
  *
@@ -400,8 +400,8 @@ void Python(void)
 
   printf(
       "/* This code is automatically generated.  "
-      "Changes made here will be lost. */\n#define NO_IMPORT_ARRAY\n"
-      "#include \"pygetdata.h\"\n"
+      "Changes made here will be lost. */\n"
+      "#include \"gdpy_intern.h\"\n"
       "const struct gdpy_constant_t gdpy_constant_list[] = {\n");
   
   for (i = 0; constant_list[i].lname != NULL; ++i)
@@ -576,9 +576,8 @@ void PHP(void)
   
   for (i = 0; constant_list[i].lname != NULL; ++i)
     if (constant_list[i].type != GDMP_DEPERR)
-      printf("zend_register_long_constant(ZEND_STRS(\"%s\"), %li, CONST_CS, "
-          "module_number TSRMLS_CC);", constant_list[i].lname,
-          constant_list[i].value);
+      printf("GDPHP_REGISTER_LONG_CONSTANT(\"%s\", %li, module_number); ",
+          constant_list[i].lname, constant_list[i].value);
 
   puts("dreturnvoid();}");
 }
