@@ -196,8 +196,7 @@ static void gdpy_set_entry_from_tuple(gd_entry_t *E, PyObject *tuple,
   size = PyTuple_Size(tuple);
   if (size < min) {
     PyErr_Format(PyExc_TypeError, "'pygetdata.entry' "
-        "%s: needed %d entry parameters, but got only %" PRIdSIZE,
-        name, min, size);
+        "%s: needed %d entry parameters, but got only %li", name, min, size);
     dreturnvoid();
     return;
   }
@@ -1151,7 +1150,7 @@ static int gdpy_entry_setspf(struct gdpy_entry_t *self, PyObject *value,
     void *closure)
 {
   unsigned int spf = 0;
-  char *scalar;
+  char *scalar = NULL;
 
   dtrace("%p, %p, %p", self, value, closure);
 
@@ -1587,7 +1586,7 @@ static int gdpy_entry_setbitnum(struct gdpy_entry_t *self, PyObject *value,
     void *closure)
 {
   int bitnum = 0;
-  char *scalar;
+  char *scalar = NULL;
   dtrace("%p, %p, %p", self, value, closure);
 
   if (self->E->field_type != GD_BIT_ENTRY &&
@@ -1768,7 +1767,7 @@ static int gdpy_entry_setshift(struct gdpy_entry_t *self, PyObject *value,
     void *closure)
 {
   int64_t shift = 0;
-  char *scalar;
+  char *scalar = NULL;
 
   dtrace("%p, %p, %p", self, value, closure);
 
@@ -1819,7 +1818,7 @@ static int gdpy_entry_setcountval(struct gdpy_entry_t *self, PyObject *value,
     void *closure)
 {
   int count_val = 0;
-  char *scalar;
+  char *scalar = NULL;
 
   dtrace("%p, %p, %p", self, value, closure);
 
@@ -2334,7 +2333,7 @@ static int gdpy_entry_setthreshold(struct gdpy_entry_t *self, PyObject *value,
     void *closure)
 {
   gd_triplet_t t;
-  char *scalar;
+  char *scalar = NULL;
 
   dtrace("%p, %p, %p", self, value, closure);
 
